DLPackTensorRef

Struct DLPackTensorRef 

pub struct DLPackTensorRef<'a> {
    pub raw: DLTensor,
    /* private fields */
}
A reference to a DLPack tensor, with data borrowed from some owner, potentially in another language.

Fields

raw: DLTensor

Implementations

Source

impl<'a> DLPackTensorRef<'a>

pub unsafe fn from_raw(tensor: DLTensor) -> DLPackTensorRef<'a>

Create a DLPackTensorRef from a raw DLTensor

Safety

The lifetime of the returned reference should be constrained to the actual lifetime of the DLTensor.

pub fn data_ptr<T>(&self) -> Result<*const T, CastError>

Get a pointer to data in this tensor. This pointer can be a device pointer according to DLPackTensorRef::device.

pub fn device(&self) -> DLDevice

Get the device where the data of this tensor lives.

pub fn dtype(&self) -> DLDataType

Get the data type of this tensor

pub fn n_dims(&self) -> usize

Get the number of dimensions of this tensor

pub fn shape(&self) -> &[i64]

Get the shape of this tensor

pub fn strides(&self) -> Option<&[i64]>

Get the strides of this tensor, if any

pub fn byte_offset(&self) -> usize

Get the byte offset of this tensor, i.e. how many bytes should be added to DLPackTensorRef::data_ptr to get the first element of the tensor.

pub fn as_dltensor(&self) -> &DLTensor

Get a reference to the underlying DLTensor