ReadOnly

Struct ReadOnly 

pub struct ReadOnly<T>(pub T);
Small wrapper type to mark a tensor as read-only when there is a choice between a read-only and a read-write implementation.

Tuple Fields

0: T