pub struct DLPackTensorRef<'a> {
pub raw: DLTensor,
/* private fields */
}Expand description
A reference to a DLPack tensor, with data borrowed from some owner, potentially in another language.
Fields
raw: DLTensorImplementations
Sourceimpl<'a> DLPackTensorRef<'a>
impl<'a> DLPackTensorRef<'a>
Sourcepub unsafe fn from_raw(tensor: DLTensor) -> DLPackTensorRef<'a>
pub unsafe fn from_raw(tensor: DLTensor) -> DLPackTensorRef<'a>
Create a DLPackTensorRef from a raw DLTensor
Safety
The lifetime of the returned reference should be constrained to the
actual lifetime of the DLTensor.
Sourcepub fn data_ptr<T>(&self) -> Result<*const T, CastError>where
T: DLPackPointerCast,
pub fn data_ptr<T>(&self) -> Result<*const T, CastError>where
T: DLPackPointerCast,
Get a pointer to data in this tensor. This pointer can be a device
pointer according to DLPackTensorRef::device.
Sourcepub fn dtype(&self) -> DLDataType
pub fn dtype(&self) -> DLDataType
Get the data type of this tensor
Sourcepub fn byte_offset(&self) -> usize
pub fn byte_offset(&self) -> usize
Get the byte offset of this tensor, i.e. how many bytes should be added
to DLPackTensorRef::data_ptr to get the first element of the tensor.
Sourcepub fn as_dltensor(&self) -> &DLTensor
pub fn as_dltensor(&self) -> &DLTensor
Get a reference to the underlying DLTensor