pub struct ReadOnly<T>(pub T);Expand description
Small wrapper type to mark a tensor as read-only when there is a choice between a read-only and a read-write implementation.
Tuple Fields
0: TTrait Implementations
Sourceimpl<T> TryFrom<ReadOnly<Arc<RwLock<Vec<T>>>>> for DLPackTensorwhere
T: GetDLPackDataType + 'static,
impl<T> TryFrom<ReadOnly<Arc<RwLock<Vec<T>>>>> for DLPackTensorwhere
T: GetDLPackDataType + 'static,